idlehomescreen/widgetmanager/inc/wmcrkeys.h
branchRCL_3
changeset 102 ba63c83f4716
parent 93 b01126ce0bec
--- a/idlehomescreen/widgetmanager/inc/wmcrkeys.h	Wed Sep 15 12:00:00 2010 +0300
+++ b/idlehomescreen/widgetmanager/inc/wmcrkeys.h	Wed Oct 13 14:18:30 2010 +0300
@@ -20,62 +20,60 @@
 #define __WMCRKEYS_H__
 
 // WidgetManager CR key
-const TUint32 KCrWidgetManager = 0x20026F53;
-
-// ************************************************************
-// NON-LOCALISED parameters
-// ************************************************************
-
-/**  */
-const TUint32 KOviStoreEnabled = 0x1;
-
-/**  */
-const TUint32 KOviOrder = 0x2;
+const TUint32 KCrWidgetManagerm = 0x20026F53;
 
-/**  */
-const TUint32 KOviUid = 0x3;
 
-/**  */
-const TUint32 KOviAppParam = 0x4;
-
-/**  */
-const TUint32 KStoreEnabled = 0x5;
-
-/**  */
-const TUint32 KOrder = 0x6;
 
 // ************************************************************
 // LOCALISED parameters start here
-// KLangId_0                 0x7
-// KUrl_0                    0x8
-// KTitle_0                  0x9
+// Key Id's from 0x1 to 0x1E are reserved for languages.
+// LangId_0                 0x1
+// OperatorUrl_0            0x2
+// OperatorButtonText_0     0x3
 // ...
-// KLangId_1                 0xA
+// LangId_1                 0x4
 // ...
-// KLangId_9                 0x22
-// KUrl_9                    0x23
-// KTitle_9                  0x24 
+// LangId_9                 0x1C
+// OperatorUrl_9            0x1D
+// OperatorButtonText_9     0x1E 
 // ************************************************************
 
 /** localised set #0, language ID */
-const TUint32 KLangId_0 = 0x7;
-/** localised set #0, store  URL */
-const TUint32 KUrl_0 = 0x8;
-/** localised set #0, store  text */
-const TUint32 KTitle_0 = 0x9;
+const TUint32 KLangId0 = 0x1;
+/** localised set #0, Operator button URL */
+const TUint32 KOperatorButtonUrl0 = 0x2;
+/** localised set #0, Operator button text */
+const TUint32 KOperatorButtonText0 = 0x3;
 
 /** localised set #1, language ID */
-const TUint32 KLangId_1 = 0xA;
+const TUint32 KLangId1 = 0x4;
 
 /** localised set #9, language ID */
-const TUint32 KLangId_9 = 0x22;
+const TUint32 KLangId9 = 0x1C;
+
 
 // ************************************************************
-// NON-LOCALISED parameters
+// NON-LOCALISED OVI parameters
 // ************************************************************
 
+/** Key to Ovi Store Client param */
+const TUint32 KOviStoreClientParam = 0x1F;
+
+/** Key to Ovi Store client Uid */
+const TUint32 KOviStoreUid = 0x20;
+
+// ************************************************************
+// NON-LOCALISED Operator parameters
+// ************************************************************
+
+/** Key to Operator button icon */
+const TUint32 KOperatorButtonEnabled = 0x21;
+
+/** Key to Operator button icon */
+const TUint32 KOperatorButtonIcon = 0x22;
+
 /** 
- * Key to Store application type and id.
+ * Key to Operator application type and id.
  * Give ':' as separator between type and id.
  * Type can be s60, cwrt, wrt, java, qt
  * Examples:
@@ -85,13 +83,16 @@
  * java:c:/sys/bin/javastore.jar            full path for java app
  * qt:0x2001A9CA                            Application Uid as id
  */
-const TUint32 KAppTypeAndId = 0x25;
+const TUint32 KOperatorAppTypeAndId = 0x23;
+
+/** Key to Operator application param */
+const TUint32 KOperatorParam = 0x24;
 
-/** */
-const TUint32 KAppParam = 0x26;
-
-/** Key to Store icon */
-const TUint32 KIcon = 0x27;
+/** 
+ * Key to define if operator button needs to be placed to left in landscape and
+ * top on portraid. By default it's right and bottom. 
+ */
+const TUint32 KOperatorButtonHigherPriority = 0x25;
 
 
 #endif // __WMCRKEYS_H__